%define _testsdir %{_libexecdir}/lutok/tests

%define somajor 3
%define libname %mklibname %{name} %{somajor}
%define devname %mklibname %{name} -d

Summary:        Lightweight C++ API library for Lua
Name:           lutok
Version:        0.6.1
Release:        %mkrel 1
License:        BSD
Group:          Development/Other
URL:            https://github.com/freebsd/lutok/
Source0:        https://github.com/freebsd/lutok/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        README.Fedora
BuildRequires:  libatf-c++-devel >= 0.20
BuildRequires:  atf-sh-devel
BuildRequires:  pkgconfig(lua)

%description
Lutok provides thin C++ wrappers around the Lua C API to ease the
interaction between C++ and Lua.  These wrappers make intensive use of
RAII to prevent resource leakage, expose C++-friendly data types, report
errors by means of exceptions and ensure that the Lua stack is always
left untouched in the face of errors.  The library also provides a small
subset of miscellaneous utility functions built on top of the wrappers.

Lutok focuses on providing a clean and safe C++ interface; the drawback
is that it is not suitable for performance-critical environments.  In
order to implement error-safe C++ wrappers on top of a Lua C binary
library, Lutok adds several layers or abstraction and error checking
that go against the original spirit of the Lua C API and thus degrade
performance.

%package -n %{libname}
Summary:        Lightweight C++ API library for Lua
Group:          System/Libraries

%description -n %{libname}
Lutok provides thin C++ wrappers around the Lua C API to ease the
interaction between C++ and Lua.  These wrappers make intensive use of
RAII to prevent resource leakage, expose C++-friendly data types, report
errors by means of exceptions and ensure that the Lua stack is always
left untouched in the face of errors.  The library also provides a small
subset of miscellaneous utility functions built on top of the wrappers.

Lutok focuses on providing a clean and safe C++ interface; the drawback
is that it is not suitable for performance-critical environments.  In
order to implement error-safe C++ wrappers on top of a Lua C binary
library, Lutok adds several layers or abstraction and error checking
that go against the original spirit of the Lua C API and thus degrade
performance.

%files -n %{libname}
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/liblutok.so.%{somajor}{,.*}

%package -n %{devname}
Summary:        Libraries and header files for Lutok development
Group:          Development/C++
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
Provides the libraries and header files to develop applications that
use the Lutok C++ API to Lua.

%files -n %{devname}
%{_includedir}/lutok
%{_libdir}/liblutok.so
%{_libdir}/pkgconfig/lutok.pc

%package doc
Summary:        API documentation of the Lutok library and example programs
Group:          Documentation
BuildArch:      noarch

%description doc
Provides HTML documentation describing the API of the Lutok library
and a collection of sample source programs to demonstrate the use
of the library.

%files doc
%{_defaultdocdir}/lutok-doc-%{version}

%package tests
Summary:        Run-time tests of the Lutok library
Group:          Development/Tools
Requires:       %{libname} = %{version}-%{release}
Requires:       %{devname} = %{version}-%{release}

%description tests
This package installs the run-time tests for the Lutok library.
Please see the README.Fedora file in the documentation directory for further
details on how to run the installed tests.

%files tests
%doc README.Fedora
%{_testsdir}


%prep
%setup -q

# Put the README.Fedora file in the top-level directory of the source tree so
# that the %%doc call below can pick it up.
cp -p %{SOURCE1} README.Fedora

%build
%configure --docdir=%{_defaultdocdir}/lutok-doc-%{version} \
           --disable-static \
           --enable-atf \
           --htmldir=%{_defaultdocdir}/lutok-doc-%{version}/html \
           --without-doxygen
%make_build testsdir=%{_testsdir}

%check
# In order to enable this, we need to add a BuildRequires on kyua-cli.  The
# problem is that kyua-cli depends on lutok.  Introducing a circular dependency
# for this minor benefit does not seem like the best move.  After all, we can
# always install lutok-tests later and run the tests post-install.
#make check testsdir=%%{_testsdir}

%install
%make_install doc_DATA= testsdir=%{_testsdir}


%changelog
* Sat Jun 14 2025 daviddavid <daviddavid> 0.6.1-1.mga10
+ Revision: 2191024
- new version: 0.6.1

* Mon Nov 21 2022 papoteur <papoteur> 0.4-20.mga9
+ Revision: 1909920
- rebuild for atf-0.21

* Fri Mar 18 2022 umeabot <umeabot> 0.4-19.mga9
+ Revision: 1797944
- Mageia 9 Mass Rebuild

* Fri Apr 02 2021 wally <wally> 0.4-18.mga9
+ Revision: 1712762
- rebuild with lua 5.4
- drop unneeded reqs

* Mon Mar 29 2021 wally <wally> 0.4-17.mga9
+ Revision: 1711759
- build with latest lua

* Fri Feb 14 2020 umeabot <umeabot> 0.4-16.mga8
+ Revision: 1522639
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Feb 05 2019 tv <tv> 0.4-15.mga7
+ Revision: 1363380
- fix deps: doc is noarch and cannot requires a mklibname pkg

* Sun Sep 23 2018 umeabot <umeabot> 0.4-14.mga7
+ Revision: 1299387
- Mageia 7 Mass Rebuild

* Sun Jun 10 2018 wally <wally> 0.4-13.mga7
+ Revision: 1236085
- fix build on aarch64

* Sat Feb 10 2018 daviddavid <daviddavid> 0.4-12.mga7
+ Revision: 1200018
- fix requires

* Sun Nov 26 2017 ngompa <ngompa> 0.4-11.mga7
+ Revision: 1179919
- Adapt for Mageia
- imported package lutok


* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.4-5
- Rebuilt for GCC 5 C++11 ABI change

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Feb 11 2014 Julio Merino <julio@meroh.net> 0.4-2
- Depend on atf-0.20 for libatf-c++ ABI changes.

* Sat Dec 07 2013 Julio Merino <julio@meroh.net> 0.4-1
- Package updated to Lutok 0.4.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 14 2013 Julio Merino <jmmv@google.com> 0.3-1
- Package updated to Lutok 0.3.
- Lutok now supports both Lua 5.1 and 5.2.  The specific version used in this
  release depends on the Fedora branch this package is built for.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jun 18 2012 Julio Merino <jmmv@google.com> 0.2-2
- Added the lutok-tests package providing the run-time tests of Lutok, readily
  runnable by the end users.

* Wed May 30 2012 Julio Merino <jmmv@google.com> 0.2-1
- Package updated to Lutok 0.2.

* Sun May 06 2012 Julio Merino <jmmv@google.com> 0.1-2
- Made lutok-devel depend on lua-devel (needed for c_gate.hpp).
- Forced lutok and lutok-devel to depend on Lua 5.1; 5.2 is not supported
  by Lutok 0.1.

* Fri Feb 03 2012 Julio Merino <jmmv@google.com> 0.1-1
- Initial release for Fedora.
